@@ -2,7 +2,7 @@ from datetime import datetime
 from typing import List
 import pickle
 
-import plyvel
+from plyvel import DB
 
 from vnpy.trader.constant import Exchange, Interval
 from vnpy.trader.object import BarData, TickData
@@ -19,26 +19,26 @@ class LeveldbDatabase(BaseDatabase):
         filename: str = SETTINGS["database.database"]
         filepath: str = str(get_file_path(filename))
 
-        self.db: plyvel.DB = plyvel.DB(filepath, create_if_missing=True)
+        self.db: DB = DB(filepath, create_if_missing=True)
 
-        self.bar_db: plyvel.DB = self.db.prefixed_db(b"bar|")
-        self.tick_db: plyvel.DB = self.db.prefixed_db(b"tick|")
-        self.bar_overview_db: plyvel.DB = self.db.prefixed_db(b"bar_overview|")
-        self.tick_overview_db: plyvel.DB = self.db.prefixed_db(b"tick_overview|")
+        self.bar_db: DB = self.db.prefixed_db(b"bar|")
+        self.tick_db: DB = self.db.prefixed_db(b"tick|")
+        self.bar_overview_db: DB = self.db.prefixed_db(b"bar_overview|")
+        self.tick_overview_db: DB = self.db.prefixed_db(b"tick_overview|")
 
     def save_bar_data(self, bars: List[BarData], stream: bool = False) -> bool:
         """保存K线数据"""
         # 获取子数据库
         bar: BarData = bars[0]
-        prefix = generate_bar_prefix(bar.symbol, bar.exchange, bar.interval)
-        db: plyvel.DB = self.bar_db.prefixed_db(prefix.encode())
+        prefix: str = generate_bar_prefix(bar.symbol, bar.exchange, bar.interval)
+        db: DB = self.bar_db.prefixed_db(prefix.encode())
 
         # 批量写入数据
         with db.write_batch() as wb:
             for bar in bars:
                 bar.datetime = bar.datetime.astimezone(DB_TZ)       # 转换时区
-                key = str(bar.datetime).encode()
-                value = pickle.dumps(bar)
+                key: str = str(bar.datetime).encode()
+                value: bytes = pickle.dumps(bar)
                 wb.put(key, value)
 
             wb.write()
@@ -73,15 +73,15 @@ class LeveldbDatabase(BaseDatabase):
         """保存TICK数据"""
         # 获取子数据库
         tick: TickData = ticks[0]
-        prefix = generate_tick_prefix(tick.symbol, tick.exchange)
-        db: plyvel.DB = self.tick_db.prefixed_db(prefix.encode())
+        prefix: str = generate_tick_prefix(tick.symbol, tick.exchange)
+        db: DB = self.tick_db.prefixed_db(prefix.encode())
 
         # 批量写入数据
         with db.write_batch() as wb:
             for tick in ticks:
                 tick.datetime = tick.datetime.astimezone(DB_TZ)     # 转换时区
-                key = str(tick.datetime).encode()
-                value = pickle.dumps(tick)
+                key: str = str(tick.datetime).encode()
+                value: bytes = pickle.dumps(tick)
                 wb.put(key, value)
             wb.write()
 
@@ -120,8 +120,8 @@ class LeveldbDatabase(BaseDatabase):
     ) -> List[BarData]:
         """读取K线数据"""
         # 获取子数据库
-        prefix = generate_bar_prefix(symbol, exchange, interval)
-        db: plyvel.DB = self.bar_db.prefixed_db(prefix.encode())
+        prefix: str = generate_bar_prefix(symbol, exchange, interval)
+        db: DB = self.bar_db.prefixed_db(prefix.encode())
 
         # 读取数据
         bars: List[BarData] = []
@@ -147,8 +147,8 @@ class LeveldbDatabase(BaseDatabase):
     ) -> List[BarData]:
         """读取TICK数据"""
         # 获取子数据库
-        prefix = generate_tick_prefix(symbol, exchange)
-        db: plyvel.DB = self.tick_db.prefixed_db(prefix.encode())
+        prefix: str = generate_tick_prefix(symbol, exchange)
+        db: DB = self.tick_db.prefixed_db(prefix.encode())
 
         # 读取数据
         ticks: List[TickData] = []
@@ -173,11 +173,11 @@ class LeveldbDatabase(BaseDatabase):
     ) -> int:
         """删除K线数据"""
         # 获取子数据库
-        prefix = generate_bar_prefix(symbol, exchange, interval)
-        db: plyvel.DB = self.bar_db.prefixed_db(prefix.encode())
+        prefix: str = generate_bar_prefix(symbol, exchange, interval)
+        db: DB = self.bar_db.prefixed_db(prefix.encode())
 
         # 遍历删除
-        count = 0
+        count: int = 0
 
         with db.write_batch() as wb:
             for key in db.iterator(include_value=False):
@@ -198,11 +198,11 @@ class LeveldbDatabase(BaseDatabase):
     ) -> int:
         """删除TICK数据"""
         # 获取子数据库
-        prefix = generate_tick_prefix(symbol, exchange)
-        db: plyvel.DB = self.tick_db.prefixed_db(prefix.encode())
+        prefix: str = generate_tick_prefix(symbol, exchange)
+        db: DB = self.tick_db.prefixed_db(prefix.encode())
 
         # 遍历删除
-        count = 0
+        count: int = 0
 
         with db.write_batch() as wb:
             for key in db.iterator(include_value=False):
